/**
 *
 * SIROCCO
 * Copyright (C) 2011 France Telecom
 * Contact: sirocco@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 *  $Id: XMLUtils.java 190 2011-07-25 13:42:21Z dangtran $
 *
 */

package org.ow2.sirocco.vmm.agent.driver.libvirt;

import java.io.StringWriter;

import javax.xml.transform.Result;
import javax.xml.transform.Source;
import javax.xml.transform.Transformer;
import javax.xml.transform.TransformerConfigurationException;
import javax.xml.transform.TransformerException;
import javax.xml.transform.TransformerFactory;
import javax.xml.transform.dom.DOMSource;
import javax.xml.transform.stream.StreamResult;
import javax.xml.xpath.XPath;
import javax.xml.xpath.XPathConstants;
import javax.xml.xpath.XPathExpression;
import javax.xml.xpath.XPathExpressionException;
import javax.xml.xpath.XPathFactory;

import org.w3c.dom.Attr;
import org.w3c.dom.Document;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

public class XMLUtils {

    static String getAttributeValue(final Node parent, final String nodeName, final String attributeName) {
        Node child = parent.getFirstChild();
        while (child != null) {
            if (child.getNodeName().equals(nodeName)) {
                break;
            }
            child = child.getNextSibling();
        }
        if (child != null) {
            Attr sourceAttr = (Attr) child.getAttributes().getNamedItem(attributeName);
            if (sourceAttr != null) {
                return sourceAttr.getValue();
            }
            return null;
        }
        return null;
    }

    static NodeList getNodeByPath(final Document xmlDocument, final String xpathExpression) {
        try {
            // XPathFactory xpathFactory=XPathFactory.newInstance();
            XPathFactory xpathFactory = new org.apache.xpath.jaxp.XPathFactoryImpl();
            XPath xPath = xpathFactory.newXPath();
            // XPath xPath = XPathFactory.newInstance().newXPath();
            XPathExpression xPathExpression = xPath.compile(xpathExpression);
            return (NodeList) xPathExpression.evaluate(xmlDocument, XPathConstants.NODESET);
        } catch (XPathExpressionException ex) {
            ex.printStackTrace();
            return null;
        }
    }

    static String xmlToString(final Node node) {
        try {
            Source source = new DOMSource(node);
            StringWriter stringWriter = new StringWriter();
            Result result = new StreamResult(stringWriter);
            TransformerFactory factory = TransformerFactory.newInstance();
            Transformer transformer = factory.newTransformer();
            transformer.transform(source, result);
            return stringWriter.getBuffer().toString();
        } catch (TransformerConfigurationException e) {
            e.printStackTrace();
        } catch (TransformerException e) {
            e.printStackTrace();
        }
        return null;
    }

}
